==> turbina-1.3.tgz: ver1.3/messages.cpp <==
#define QT_THREAD_SUPPORT
#include <stdio.h>
#include <qthread.h>
#include <qmessagebox.h>
#include "messages.h"
#include "trberror.h"
#include "trbexport.h"

extern QMutex infoExportMutex;

void showMessage( const QString& text, int ms ) {
	infoExportMutex.lock();
	InfoExport::message = text;
	InfoExport::ms = ms;
	InfoExport::isMessage = true;
	infoExportMutex.unlock();
}

int showWarning( const QString& str, const char* retry="Retry",
			const char* ignore="Ignore",
			const char* abort="Exit"  ) {

	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_ABORT );
		return( QMessageBox::Ignore );
	}
	QMessageBox mb( "Warning",str,
		QMessageBox::Warning,
		QMessageBox::Retry,
		QMessageBox::Ignore,
		QMessageBox::Abort );
	mb.setButtonText( QMessageBox::Retry, retry );
	mb.setButtonText( QMessageBox::Ignore, ignore );
	mb.setButtonText( QMessageBox::Abort, abort );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	return( mb.exec() );
}

int showStrongWarning( const QString& str, const char* ignore="Ignore",
				const char* abort="Exit" ) {

	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_ABORT );
		return( QMessageBox::Ignore );
	}
	QMessageBox mb( "Warning",str,
		QMessageBox::Warning,
		QMessageBox::Ignore,
		QMessageBox::Abort,0 );

	mb.setButtonText( QMessageBox::Ignore, ignore );
	mb.setButtonText( QMessageBox::Abort, abort );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	return( mb.exec() );
}

int showStrongMessage( const QString& str, const char* ok="OK" ) {

	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_ABORT );
		return( QMessageBox::Ignore );
	}
	QMessageBox mb( "Warning",str,
		QMessageBox::Warning,
		QMessageBox::Ok,0,0 );
	mb.setButtonText( QMessageBox::Ok, ok );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	return( mb.exec() );
}

void showFatalError( const QString& str ) {
// Chtoby ostalos' na ecrane posle vykhoda iz programmy
	printf( "Fatal: %s...\n",str.data() );
	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_EXIT );
		return;
	}
	QMessageBox mb( "Error",str,
		QMessageBox::Critical,
		QMessageBox::Abort,0,0 );
	mb.setButtonText( QMessageBox::Abort, "Exit" );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	mb.exec();
}

==> turbina-1.32.tgz: ver1.32/messages.cpp <==
#define QT_THREAD_SUPPORT
#include <stdio.h>
#include <qthread.h>
#include <qmessagebox.h>
#include "messages.h"
#include "trberror.h"
#include "trbexport.h"

extern QMutex infoExportMutex;

void showMessage( const QString& text, int ms ) {
	infoExportMutex.lock();
	InfoExport::message = text;
	InfoExport::ms = ms;
	InfoExport::isMessage = true;
	infoExportMutex.unlock();
}

int showWarning( const QString& str, const char* retry="&Retry",
			const char* ignore="&Ignore",
			const char* abort="E&xit"  ) {

	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_ABORT );
		return( QMessageBox::Ignore );
	}
	QMessageBox mb( "Warning",str,
		QMessageBox::Warning,
		QMessageBox::Retry,
		QMessageBox::Ignore | QMessageBox::Default | QMessageBox::Escape,
		QMessageBox::Abort );
	mb.setButtonText( QMessageBox::Retry, retry );
	mb.setButtonText( QMessageBox::Ignore, ignore );
	mb.setButtonText( QMessageBox::Abort, abort );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	return( mb.exec() );
}

int showStrongWarning( const QString& str, const char* ignore="&Ignore",
				const char* abort="E&xit" ) {

	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_ABORT );
		return( QMessageBox::Ignore );
	}
	QMessageBox mb( "Warning",str,
		QMessageBox::Warning,
		QMessageBox::Ignore | QMessageBox::Default | QMessageBox::Escape,
		QMessageBox::Abort,0 );

	mb.setButtonText( QMessageBox::Ignore, ignore );
	mb.setButtonText( QMessageBox::Abort, abort );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	return( mb.exec() );
}

int showStrongMessage( const QString& str, const char* ok="OK" ) {

	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_ABORT );
		return( QMessageBox::Ignore );
	}
	QMessageBox mb( "Warning",str,
		QMessageBox::Warning,
		QMessageBox::Ok | QMessageBox::Default | QMessageBox::Escape,
			0,0 );
	mb.setButtonText( QMessageBox::Ok, ok );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	return( mb.exec() );
}

void showFatalError( const QString& str ) {
// Chtoby ostalos' na ecrane posle vykhoda iz programmy
	printf( "Fatal: %s...\n",str.data() );
	if( !trberr::dialog() ) {
		trberr::setMessage(str);
		trberr::setCode( TRB_EXIT );
		return;
	}
	QMessageBox mb( "Error",str,
		QMessageBox::Critical,
		QMessageBox::Abort,0,0 );
	mb.setButtonText( QMessageBox::Abort, "Exit" );
	mb.setPalette( QPalette( WARNING_BUTTON_COLOR, WARNING_BACK_COLOR ) );
	mb.exec();
}
